@@ -33,13 +33,6 @@ function buildThingShadowTopic(thingName, operation, type) {
    return '$aws/things/' + thingName + '/shadow/' + operation;
 }
 
-function isReservedTopic(topic) {
-   if (topic.substring(0, 12) === '$aws/things/') {
-      return true;
-   }
-   return false;
-}
-
 function isThingShadowTopic(topicTokens, direction) {
    var rc = false;
    if (topicTokens[0] === '$aws') {
@@ -711,11 +704,7 @@ function ThingShadowsClient(deviceOptions, thingShadowOptions) {
    // Publish on non-thing topics.
    //
    this.publish = function(topic, message, options, callback) {
-      if (!isReservedTopic(topic)) {
-         device.publish(topic, message, options, callback);
-      } else {
-         throw ('cannot publish to reserved topic \'' + topic + '\'');
-      }
+      device.publish(topic, message, options, callback);
    };
 
    //
@@ -728,11 +717,6 @@ function ThingShadowsClient(deviceOptions, thingShadowOptions) {
       } else if (typeof topics === 'object' && topics.length) {
          topicsArray = topics;
       }
-      for (var i = 0; i < topicsArray.length; i++) {
-         if (isReservedTopic(topicsArray[i])) {
-            throw ('cannot subscribe to topic array since one of them is a reserved topic \'' + topicsArray[i] + '\'');
-         }
-      }
       device.subscribe(topicsArray, options, callback);
    };
    //
@@ -745,11 +729,6 @@ function ThingShadowsClient(deviceOptions, thingShadowOptions) {
       } else if (typeof topics === 'object' && topics.length) {
          topicsArray = topics;
       }
-      for (var i = 0; i < topicsArray.length; i++) {
-         if (isReservedTopic(topicsArray[i])) {
-            throw ('cannot unsubscribe from topic array since one of them is a reserved topic \'' + topicsArray[i] + '\'');
-         }
-      }
       device.unsubscribe(topicsArray, callback);
    };
    //
